#boduch - Simple Python tool library.
#   Copyright (C) 2008  Adam Boduch
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as
#   published by the Free Software Foundation, either version 3 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""This module defines the interface for the event thread class."""

from zope.interface import Interface, Attribute

class IEventThread(Interface):
    """The event thread class must store a list of handles to execute
    and must define a run method which actually executes the handles."""
    handles=Attribute("The handles that are executed by this thread.")
    
    def run(self):
        """Run the thread and in turn, execute all the handlers for the
        event."""
        
__all__=['IEventThread']