#boduch - Simple Python tool library.
#   Copyright (C) 2008  Adam Boduch
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as
#   published by the Free Software Foundation, either version 3 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""This module defines constants that identify primitive types."""

TYPE_BOOL=       "BOOL"
TYPE_BOOLEAN=    "BOOLEAN"
TYPE_INT=        "INT"
TYPE_INTEGER=    "INTEGER"
TYPE_LONG=       "LONG"
TYPE_FLOAT=      "FLOAT"
TYPE_STR=        "STR"
TYPE_STRING=     "STRING"
TYPE_UNICODE=    "UNICODE"
TYPE_TUPLE=      "TUPLE"
TYPE_LIST=       "LIST"
TYPE_DICT=       "DICT"
TYPE_DICTIONARY= "DICTIONARY"

__all__=['TYPE_BOOL', 'TYPE_BOOLEAN', 'TYPE_INT', 'TYPE_INTEGER', 'TYPE_LONG',\
         'TYPE_FLOAT', 'TYPE_STR', 'TYPE_STRING', 'TYPE_UNICODE',\
         'TYPE_TUPLE', 'TYPE_LIST', 'TYPE_DICT', 'TYPE_DICTIONARY']